==> open-xchange-documents-backend_7.8.4.orig.tar.bz2: open-xchange-documents-backend-7.8.4/com.openexchange.office.rest/src/com/openexchange/office/rest/DocumentRESTActionFactory.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.office.rest;

import java.util.Collection;
import java.util.HashMap;
import java.util.Map;

import com.openexchange.ajax.requesthandler.AJAXActionService;
import com.openexchange.ajax.requesthandler.AJAXActionServiceFactory;
import com.openexchange.office.document.LocalFileMappingManager;
import com.openexchange.office.document.TemplateFilesScanner;
import com.openexchange.office.imagemgr.ResourceManager;
import com.openexchange.office.tools.doc.EmptyDocumentCache;
import com.openexchange.server.ServiceLookup;

/**
 * {@link DocumentRESTActionFactory}
 *
 * @author <a href="mailto:kai.ahrens@open-xchange.com">Kai Ahrens</a>
 */
public class DocumentRESTActionFactory implements AJAXActionServiceFactory {

    private final Map<String, AJAXActionService> actions = new HashMap<String, AJAXActionService>();
    private ResourceManager resourceManager = null;
    private TemplateFilesScanner templateFilesScanner = null;
    private LocalFileMappingManager localFileMapper = null;
    private EmptyDocumentCache emptyDocCache = null;

    /**
     * Initializes a new {@link DocumentRESTActionFactory}.
     */
    public DocumentRESTActionFactory(final ServiceLookup servicesDEPRECATED) {
        super();

        resourceManager = new ResourceManager(null);
        localFileMapper = new LocalFileMappingManager();
        templateFilesScanner = new TemplateFilesScanner(null, localFileMapper, TemplateFilesScanner.TemplateFilterType.ALL_DOCUMENTS);
        emptyDocCache = new EmptyDocumentCache();

        actions.put("addfile", new AddFileAction(null, resourceManager));
        actions.put("createdefaultdocument", new CreateDefaultDocumentAction(null, emptyDocCache));
        actions.put("getdocument", new GetDocumentAction(null));
        actions.put("getfeatures", new GetFeaturesAction(null));
        actions.put("getfile", new GetFileAction(null, resourceManager));
        actions.put("renamedocument", new RenameDocumentAction(null));
        actions.put("updateview", new UpdateViewAction(null));
        actions.put("replaceAll", new ReplaceAllAction(null));
        actions.put("query", new QueryAction(null));
        actions.put("copy", new CopyAction(null));
        actions.put("paste", new PasteAction(null));
        actions.put("gethtmlcode", new GetHtmlCodeAction(null));
        actions.put("copydocument", new CopyDocumentAction(null));
        actions.put("gettemplatelist", new GetTemplateListAction(null, templateFilesScanner));
        actions.put("createfromtemplate", new CreateFromTemplateAction(null, localFileMapper));
        actions.put("templatepreview", new TemplatePreviewAction(null, localFileMapper));
        actions.put("gettemplateandrecentlist", new GetTemplateAndRecentListAction(null, templateFilesScanner));
        actions.put("deletefilefromrecentlist", new DeleteFileFromRecentListAction(null));
        actions.put("clearrecentlist", new ClearRecentListAction(null));
        actions.put("prefetchofficeparts", new PrefetchOfficePartsAction(null, emptyDocCache));
        actions.put("getuserinfo", new GetUserInfoAction(null));
        actions.put("sort", new SortAction(null));
        actions.put("getcontexttemplatefolders", new GetContextTemplateFoldersAction(null));
        actions.put("saveaswithbackup", new SaveAsWithBackupAction(null));
    }

    @Override
    public AJAXActionService createActionService(final String action) {
        return (actions.get(action));
    }

    @Override
    public Collection<? extends AJAXActionService> getSupportedServices() {
        return java.util.Collections.unmodifiableCollection(actions.values());
    }
}

==> open-xchange-documents-backend_7.10.1.orig.tar.bz2: open-xchange-documents-backend-7.10.1/com.openexchange.office.rest/src/com/openexchange/office/rest/DocumentRESTActionFactory.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.office.rest;

import java.util.Collection;
import java.util.HashMap;
import java.util.Map;
import com.openexchange.ajax.requesthandler.AJAXActionService;
import com.openexchange.ajax.requesthandler.AJAXActionServiceFactory;
import com.openexchange.office.document.EmptyDocumentCache;
import com.openexchange.office.document.LocalFileMappingManager;
import com.openexchange.office.document.TemplateFilesScanner;
import com.openexchange.office.imagemgr.ResourceManager;
import com.openexchange.office.tools.config.ConfigurationHelper;
import com.openexchange.server.ServiceLookup;

/**
 * {@link DocumentRESTActionFactory}
 *
 * @author <a href="mailto:kai.ahrens@open-xchange.com">Kai Ahrens</a>
 */
public class DocumentRESTActionFactory implements AJAXActionServiceFactory {

    private final Map<String, AJAXActionService> actions = new HashMap<String, AJAXActionService>();
    private ResourceManager resourceManager = null;
    private TemplateFilesScanner templateFilesScanner = null;
    private LocalFileMappingManager localFileMapper = null;
    private EmptyDocumentCache emptyDocCache = null;
    private LogPerformanceDataWriter logPerformanceDataWriter = null;

    /**
     * Initializes a new {@link DocumentRESTActionFactory}.
     */
    public DocumentRESTActionFactory(final ServiceLookup servicesDEPRECATED) {
        super();

        resourceManager = new ResourceManager();
        localFileMapper = new LocalFileMappingManager();
        templateFilesScanner = new TemplateFilesScanner(null, localFileMapper, TemplateFilesScanner.TemplateFilterType.ALL_DOCUMENTS);
        emptyDocCache = new EmptyDocumentCache();
        logPerformanceDataWriter = new LogPerformanceDataWriter();

        actions.put("addfile", new AddFileAction(null, resourceManager));
        actions.put("createdefaultdocument", new CreateDefaultDocumentAction(null, emptyDocCache));
        actions.put("getdocument", new GetDocumentAction(null));
        actions.put("getfeatures", new GetFeaturesAction(null));
        actions.put("getfile", new GetFileAction(null, resourceManager));
        actions.put("renamedocument", new RenameDocumentAction(null));
        actions.put("updateview", new UpdateViewAction(null));
        actions.put("replaceAll", new ReplaceAllAction(null));
        actions.put("query", new QueryAction(null));
        actions.put("copy", new CopyAction(null));
        actions.put("paste", new PasteAction(null));
        actions.put("gethtmlcode", new GetHtmlCodeAction(null));
        actions.put("copydocument", new CopyDocumentAction(null));
        actions.put("gettemplatelist", new GetTemplateListAction(null, templateFilesScanner));
        actions.put("createfromtemplate", new CreateFromTemplateAction(null, localFileMapper));
        actions.put("templatepreview", new TemplatePreviewAction(null, localFileMapper));
        actions.put("gettemplateandrecentlist", new GetTemplateAndRecentListAction(null, templateFilesScanner));
        actions.put("deletefilefromrecentlist", new DeleteFileFromRecentListAction(null));
        actions.put("clearrecentlist", new ClearRecentListAction(null));
        actions.put("prefetchofficeparts", new PrefetchOfficePartsAction(null, emptyDocCache));
        actions.put("getuserinfo", new GetUserInfoAction(null));
        actions.put("sort", new SortAction(null));
        actions.put("getcontexttemplatefolders", new GetContextTemplateFoldersAction(null));
        actions.put("saveaswithbackup", new SaveAsWithBackupAction(null));
        actions.put("getoperations", new GetOperationsAction(null));
        actions.put("logperformancedata", new LogPerformanceDataAction(null, logPerformanceDataWriter));
    }

    @Override
    public AJAXActionService createActionService(final String action) {
        return (actions.get(action));
    }

    public Collection<? extends AJAXActionService> getSupportedServices() {
        return java.util.Collections.unmodifiableCollection(actions.values());
    }

    public void shutdown() {
        final LogPerformanceDataWriter aDataWriter = logPerformanceDataWriter;
        if (null != aDataWriter) {
            aDataWriter.shutdown();
        }

        final GetOperationsAction getOperationsAction = (GetOperationsAction)actions.get("getoperations");
        if (null != getOperationsAction) {
            getOperationsAction.shutdown();
        }
    }
}
